==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>비디오 녹화가 진행 중입니다. 창을 닫으시겠습니까?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">폴더 열기</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>카메라 변경하기</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>이 폴더를 조작할 수 있는 권한이 없습니다.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">올바르지 않은 폴더</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File location</source>
        <translation>파일 위치</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Burst mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>출력 형식</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 pcs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>카메라는 PC 카메라 또는 웹캠을 사용하는 이미지 및 비디오 캡처 유틸리티입니다.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>파일이 저장되지 않음</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">저장 위치:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>사진:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>비디오:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>해상도 설정</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">해상도:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>사진:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>비디오:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>음향 효과</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>녹화 중지</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 보이기</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>사진 촬영 중지</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">사진 찍기</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">비디오 녹화</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">사진 촬영 중지</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>웹캠을 찾을 수 없음</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>웹캠이 사용 중입니다</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">녹화 중지</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>비디오 녹화가 진행 중입니다. 창을 닫으시겠습니까?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">폴더 열기</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>카메라 변경하기</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>이 폴더를 조작할 수 있는 권한이 없습니다.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">올바르지 않은 폴더</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>기본</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>파일 위치</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>사진 촬영</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>버스트 모드</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>자체 타이머 지연 시간</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>출력 형식</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4개</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10개</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>카메라는 PC 카메라 또는 웹캠을 사용하는 이미지 및 비디오 캡처 유틸리티입니다.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>파일이 저장되지 않음</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">저장 위치:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>사진:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>비디오:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>해상도 설정</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">해상도:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>사진:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>비디오:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>음향 효과</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>거울 모드</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>플래시라이트</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>그리드라인</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1x1 줄</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2x2 줄</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>최대 해상도:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>녹화 중지</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 보이기</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>사진 촬영 중지</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>컨텍스트 메뉴</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">사진 찍기</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">비디오 녹화</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">사진 촬영 중지</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>정상</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>생동감 있는</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>따뜻한</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>차가운</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>레트로</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>필름</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>흑백</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>플래시라이트</translation>
    </message>
    <message>
        <source>On</source>
        <translation>켜짐</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>꺼짐</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>지연 촬영</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>필터</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>노출</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>웹캠을 찾을 수 없음</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>웹캠이 사용 중입니다</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">녹화 중지</translation>
    </message>
</context>
</TS>
